@@ -141,12 +141,12 @@ AString BinaryFile::getFilename() const
 
 bool BinaryFile::getOpenForRead()
 {
-    return (m_curMode | READ) != 0;
+    return (m_curMode & READ) != 0;
 }
 
 bool BinaryFile::getOpenForWrite()
 {
-    return (m_curMode | WRITE) != 0;
+    return (m_curMode & WRITE) != 0;
 }
 
 void BinaryFile::open(const AString& filename, const OpenMode& opmode)
@@ -390,6 +390,7 @@ void QFileImpl::read(void* dataOut, const int64_t& count, int64_t* numRead)
 
 void QFileImpl::seek(const int64_t& position)
 {
+    if (m_file.pos() == position) return; //QFile::seek always does a flush in qt5, so try to avoid calling it
     if (!m_file.seek(position)) throw CiftiException("seek failed in file '" + m_fileName + "'");
 }
 
